@@ -1,5 +1,6 @@
 from tensorflow.keras.models import load_model
 from tensorflow.keras.utils import get_file 
+import os
 import matplotlib.pyplot as plt
 import numpy as np
 from skimage.transform import resize,rescale
@@ -51,8 +52,9 @@ def add_noise(im,sensitivity = 0.1,invert = False,seed = 42):
 
 
 class MISIC():
-    def __init__(self,model_name = 'MiSiC/MiSiDC04082020.h5'):
+    def __init__(self):        
         #model_path = get_file('misic_model','https://github.com/pswapnesh/Models/raw/master/MiSiDC04082020.h5') ## 0721
+        model_name = os.path.join(os.path.dirname(__file__), 'MiSiDC04082020.h5');
         self.model = load_model(model_name,compile=False)
         self.model.compile(optimizer='adam',loss='categorical_crossentropy',metrics=['accuracy'])
         self.size = 256        
